ui

package
v0.1.2 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 18, 2026 License: Apache-2.0 Imports: 28 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type App

type App struct {
	// contains filtered or unexported fields
}

App is the root Bubble Tea model.

func NewApp

func NewApp(cfg *config.Config, b backend.Backend, initialPath string, logger *log.Logger, lp logpanel.Model) App

NewApp creates the root application model. If b is nil, the profile picker is shown on startup.

func (App) Init

func (a App) Init() tea.Cmd

func (App) Update

func (a App) Update(msg tea.Msg) (tea.Model, tea.Cmd)

func (App) View

func (a App) View() string

Directories

Path Synopsis
editor
Package icons maps file names and extensions to Nerd Font glyphs.
Package icons maps file names and extensions to Nerd Font glyphs.

Jump to